@@ -1,5 +1,5 @@
 "Main interface for qldb service"
-from mypy_boto3_qldb.client import QLDBClient as Client, QLDBClient
+from mypy_boto3_qldb.client import QLDBClient, QLDBClient as Client
 
 
 __all__ = ("Client", "QLDBClient")
